@@ -481,21 +481,24 @@ parse_kate_modeline (gchar           *s,
 	return s;
 }
 
+/* Scan a line for vi(m)/emacs/kate modelines.
+ * Line numbers are counted starting at one.
+ */
 static void
 parse_modeline (gchar           *s,
 		gint             line_number,
 		gint             line_count,
 		ModelineOptions *options)
 {
-	gchar prev = ' ';
+	gchar prev;
 
 	/* look for the beginning of a modeline */
-	for (; *s != '\0'; prev = *(s++))
+	for (prev = ' '; (s != NULL) && (*s != '\0'); prev = *(s++))
 	{
 		if (!g_ascii_isspace (prev))
 			continue;
 
-		if ((line_number < 3 || line_number >= line_count - 3) &&
+		if ((line_number <= 3 || line_number > line_count - 3) &&
 		    (strncmp (s, "ex:", 3) == 0 ||
 		     strncmp (s, "vi:", 3) == 0 ||
 		     strncmp (s, "vim:", 4) == 0))
@@ -505,13 +508,13 @@ parse_modeline (gchar           *s,
 		    	while (*s != ':') s++;
 		    	s = parse_vim_modeline (s + 1, options);
 		}
-		else if (line_number < 2 && strncmp (s, "-*-", 3) == 0)
+		else if (line_number <= 2 && strncmp (s, "-*-", 3) == 0)
 		{
 			gedit_debug_message (DEBUG_PLUGINS, "Emacs modeline on line %d", line_number);
 
 			s = parse_emacs_modeline (s + 3, options);
 		}
-		else if ((line_number < 10 || line_number >= line_count - 10) &&
+		else if ((line_number <= 10 || line_number > line_count - 10) &&
 			 strncmp (s, "kate:", 5) == 0)
 		{
 			gedit_debug_message (DEBUG_PLUGINS, "Kate modeline on line %d", line_number);
@@ -527,7 +530,6 @@ modeline_parser_apply_modeline (GtkSourceView *view)
 	ModelineOptions options;
 	GtkTextBuffer *buffer;
 	GtkTextIter iter, liter;
-	gint line_number;
 	gint line_count;
 
 	/* Default values for modeline options */
@@ -543,11 +545,12 @@ modeline_parser_apply_modeline (GtkSourceView *view)
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	gtk_text_buffer_get_start_iter (buffer, &iter);
-	line_number = 0;
+
 	line_count = gtk_text_buffer_get_line_count (buffer);
 
 	/* Parse the modelines on the 10 first lines... */
-	while (line_number < 10 && line_number < line_count)
+	while ((gtk_text_iter_get_line (&iter) < 10) &&
+	       !gtk_text_iter_is_end (&iter))
 	{
 		gchar *line;
 
@@ -555,23 +558,36 @@ modeline_parser_apply_modeline (GtkSourceView *view)
 		gtk_text_iter_forward_to_line_end (&iter);
 		line = gtk_text_buffer_get_text (buffer, &liter, &iter, TRUE);
 
-		parse_modeline (line, line_number, line_count, &options);
+		parse_modeline (line,
+				1 + gtk_text_iter_get_line (&iter),
+				line_count,
+				&options);
+
+		gtk_text_iter_forward_line (&iter);
 
 		g_free (line);
-		line_number ++;
 	}
 
 	/* ...and on the 10 last ones (modelines are not allowed in between) */
-	if (line_number < line_count - 10)
+	if (!gtk_text_iter_is_end (&iter))
 	{
-		guint remaining_lines = line_count - line_number - 1;
-		gtk_text_buffer_get_end_iter (buffer, &iter);
-		gtk_text_iter_backward_lines (&iter,
-					      MIN (10, remaining_lines));
-		line_number = line_count - 11;
+		gint cur_line;
+		guint remaining_lines;
+
+		/* we are on the 11th line (count from 0) */
+		cur_line = gtk_text_iter_get_line (&iter);
+		/* g_assert (10 == cur_line); */
+
+		remaining_lines = line_count - cur_line - 1;
+
+		if (remaining_lines > 10)
+		{
+			gtk_text_buffer_get_end_iter (buffer, &iter);
+			gtk_text_iter_backward_lines (&iter, 9);
+		}
 	}
 
-	while (line_number < line_count)
+	while (!gtk_text_iter_is_end (&iter))
 	{
 		gchar *line;
 
@@ -579,10 +595,14 @@ modeline_parser_apply_modeline (GtkSourceView *view)
 		gtk_text_iter_forward_to_line_end (&iter);
 		line = gtk_text_buffer_get_text (buffer, &liter, &iter, TRUE);
 
-		parse_modeline (line, line_number, line_count, &options);
+		parse_modeline (line,
+				1 + gtk_text_iter_get_line (&iter),
+				line_count,
+				&options);
+
+		gtk_text_iter_forward_line (&iter);
 
 		g_free (line);
-		line_number ++;
 	}
 
 	/* Try to set language */
